@@ -1,5 +1,4 @@
 __all__ = ["Comm", "CommManager"]
 
-from comm.base_comm import CommManager  # noqa
-
 from .comm import Comm  # noqa
+from .manager import CommManager
