@@ -9,12 +9,13 @@ import typing as t
 from contextlib import contextmanager
 from functools import partial
 
+import comm
 from IPython.core import release
 from IPython.utils.tokenutil import line_at_cursor, token_at_cursor
 from traitlets import Any, Bool, Instance, List, Type, observe, observe_compat
 from zmq.eventloop.zmqstream import ZMQStream
 
-from .comm import CommManager
+from .comm.comm import BaseComm
 from .compiler import XCachingCompiler
 from .debugger import Debugger, _is_debugpy_available
 from .eventloops import _use_appnope
@@ -39,6 +40,14 @@ except ImportError:
 _EXPERIMENTAL_KEY_NAME = "_jupyter_types_experimental"
 
 
+def create_comm(*args, **kwargs):
+    """Create a new Comm."""
+    return BaseComm(*args, **kwargs)
+
+
+comm.create_comm = create_comm
+
+
 class IPythonKernel(KernelBase):
     shell = Instance("IPython.core.interactiveshell.InteractiveShellABC", allow_none=True)
     shell_class = Type(ZMQInteractiveShell)
@@ -101,7 +110,7 @@ class IPythonKernel(KernelBase):
         self.shell.display_pub.session = self.session
         self.shell.display_pub.pub_socket = self.iopub_socket
 
-        self.comm_manager = CommManager(parent=self, kernel=self)
+        self.comm_manager = comm.get_comm_manager()
 
         self.shell.configurables.append(self.comm_manager)
         comm_msg_types = ["comm_open", "comm_msg", "comm_close"]
@@ -243,7 +252,7 @@ class IPythonKernel(KernelBase):
 
         getpass.getpass = self._save_getpass
 
-    @property  # type:ignore[override]
+    @property
     def execution_count(self):
         return self.shell.execution_count
 
@@ -451,7 +460,6 @@ class IPythonKernel(KernelBase):
             cursor_pos = len(code)
         line, offset = line_at_cursor(code, cursor_pos)
         line_cursor = cursor_pos - offset
-
         txt, matches = self.shell.complete("", line, line_cursor)
         return {
             "matches": matches,
@@ -580,14 +588,16 @@ class IPythonKernel(KernelBase):
         return r
 
     def do_apply(self, content, bufs, msg_id, reply_metadata):
-        from .serialize import serialize_object, unpack_apply_message
+        try:
+            from ipyparallel.serialize import serialize_object, unpack_apply_message
+        except ImportError:
+            from .serialize import serialize_object, unpack_apply_message  # type:ignore
 
         shell = self.shell
         try:
             working = shell.user_ns
 
             prefix = "_" + str(msg_id).replace("-", "") + "_"
-
             f, args, kwargs = unpack_apply_message(bufs, working, copy=False)
 
             fname = getattr(f, "__name__", "f")
@@ -650,7 +660,7 @@ class IPythonKernel(KernelBase):
 
 
 class Kernel(IPythonKernel):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs):  # pragma: no cover
         import warnings
 
         warnings.warn(
