@@ -4,23 +4,32 @@
 # Distributed under the terms of the Modified BSD License.
 
 import os
+import unittest
+import warnings
 from queue import Queue
 from threading import Thread
-import unittest
+from unittest.mock import MagicMock
 
-from traitlets import Int
+import pytest
 import zmq
-
-from ipykernel.zmqshell import ZMQDisplayPublisher
 from jupyter_client.session import Session
+from traitlets import Int
+
+from ipykernel.zmqshell import (
+    InteractiveShell,
+    KernelMagics,
+    ZMQDisplayPublisher,
+    ZMQInteractiveShell,
+)
 
 
-class NoReturnDisplayHook(object):
+class NoReturnDisplayHook:
     """
     A dummy DisplayHook which allows us to monitor
     the number of times an object is called, but which
     does *not* return a message when it is called.
     """
+
     call_count = 0
 
     def __call__(self, obj):
@@ -33,8 +42,9 @@ class ReturnDisplayHook(NoReturnDisplayHook):
     as its base class, but which also returns the same
     message when it is called.
     """
+
     def __call__(self, obj):
-        super(ReturnDisplayHook, self).__call__(obj)
+        super().__call__(obj)
         return obj
 
 
@@ -44,6 +54,7 @@ class CounterSession(Session):
     the calls made to the session object by the display
     publisher.
     """
+
     send_count = Int(0)
 
     def send(self, *args, **kwargs):
@@ -52,7 +63,7 @@ class CounterSession(Session):
         with an increment to the send counter.
         """
         self.send_count += 1
-        super(CounterSession, self).send(*args, **kwargs)
+        super().send(*args, **kwargs)
 
 
 class ZMQDisplayPublisherTests(unittest.TestCase):
@@ -65,10 +76,7 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         self.socket = self.context.socket(zmq.PUB)
         self.session = CounterSession()
 
-        self.disp_pub = ZMQDisplayPublisher(
-            session = self.session,
-            pub_socket = self.socket
-        )
+        self.disp_pub = ZMQDisplayPublisher(session=self.session, pub_socket=self.socket)
 
     def tearDown(self):
         """
@@ -96,14 +104,18 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         initialised with an empty list for the display hooks
         """
         assert self.disp_pub._hooks == []
+
         def hook(msg):
             return msg
+
         self.disp_pub.register_hook(hook)
         assert self.disp_pub._hooks == [hook]
 
         q = Queue()
+
         def set_thread_hooks():
             q.put(self.disp_pub._hooks)
+
         t = Thread(target=set_thread_hooks)
         t.start()
         thread_hooks = q.get(timeout=10)
@@ -114,7 +126,7 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         Publish should prepare the message and eventually call
         `send` by default.
         """
-        data = dict(a = 1)
+        data = dict(a=1)
         assert self.session.send_count == 0
         self.disp_pub.publish(data)
         assert self.session.send_count == 1
@@ -126,7 +138,7 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         the message has been consumed, and should not be
         processed (`sent`) in the normal manner.
         """
-        data = dict(a = 1)
+        data = dict(a=1)
         hook = NoReturnDisplayHook()
 
         self.disp_pub.register_hook(hook)
@@ -162,7 +174,7 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         Once a hook is unregistered, it should not be called
         during `publish`.
         """
-        data = dict(a = 1)
+        data = dict(a=1)
         hook = NoReturnDisplayHook()
 
         self.disp_pub.register_hook(hook)
@@ -181,7 +193,7 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         # at the end.
         #
         # As a result, the hook call count should *not* increase,
-        # but the session send count *should* increase.
+        # but the session send count *should* increase.
         #
         first = self.disp_pub.unregister_hook(hook)
         self.disp_pub.publish(data)
@@ -198,5 +210,49 @@ class ZMQDisplayPublisherTests(unittest.TestCase):
         self.assertFalse(second)
 
 
-if __name__ == '__main__':
+def test_magics(tmp_path):
+    context = zmq.Context()
+    socket = context.socket(zmq.PUB)
+    shell = InteractiveShell()
+    shell.user_ns["hi"] = 1
+    magics = KernelMagics(shell)
+
+    def find_edit_target(*args):
+        return str(tmp_path), 0, 1
+
+    tmp_file = tmp_path / "test.txt"
+    tmp_file.write_text("hi", "utf8")
+    magics._find_edit_target = find_edit_target
+    magics.edit("hi")
+    magics.clear([])
+    magics.less(str(tmp_file))
+    if os.name == "posix":
+        magics.man("ls")
+    magics.autosave("10")
+
+    socket.close()
+    context.destroy()
+
+
+def test_zmq_interactive_shell(kernel):
+    shell = ZMQInteractiveShell()
+
+    with pytest.raises(RuntimeError):
+        shell.enable_gui("tk")
+
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", DeprecationWarning)
+        shell.data_pub_class = MagicMock()
+        shell.data_pub
+    shell.kernel = kernel
+    shell.set_next_input("hi")
+    assert shell.get_parent() is None
+    if os.name == "posix":
+        shell.system_piped("ls")
+    else:
+        shell.system_piped("dir")
+    shell.ask_exit()
+
+
+if __name__ == "__main__":
     unittest.main()
