@@ -285,7 +285,7 @@ class KernelMagics(Magics):
         opts, args = self.parse_options(parameter_s, "prn:")
 
         try:
-            filename, lineno, _ = CodeMagics._find_edit_target(self.shell, args, opts, last_call)
+            filename, lineno, _ = self._find_edit_target(self.shell, args, opts, last_call)
         except MacroToEdit:
             # TODO: Implement macro editing over 2 processes.
             print("Macro editing not yet implemented in 2-process model.")
@@ -326,7 +326,8 @@ class KernelMagics(Magics):
         if arg_s.endswith(".py"):
             cont = self.shell.pycolorize(openpy.read_py_file(arg_s, skip_encoding_cookie=False))
         else:
-            cont = open(arg_s).read()
+            with open(arg_s) as fid:
+                cont = fid.read()
         page.page(cont)
 
     more = line_magic("more")(less)
@@ -482,6 +483,9 @@ class ZMQInteractiveShell(InteractiveShell):
         # These two ensure 'ls' produces nice coloring on BSD-derived systems
         env["TERM"] = "xterm-color"
         env["CLICOLOR"] = "1"
+        # These two add terminal color in tools that support it.
+        env["FORCE_COLOR"] = "1"
+        env["CLICOLOR_FORCE"] = "1"
         # Since normal pagers don't work at all (over pexpect we don't have
         # single-key control of the subprocess), try to disable paging in
         # subprocesses as much as possible.
